import { HttpCRUDTranslator } from '@/http-crud-translator/http-crud-translator';
import {
    AlertService, Select, Textarea, TextInput,
} from '@zeedhi/common';
import { Metadata } from '@zeedhi/core';

export class FmtSolicitacaoServicoController {
    // @toDo: pegar esse valor do local storage
    public atualNrFunc = 2;

    public responsavel: string = '';

    public dataSolicitacao: string = new Date(Date.now()).toISOString();

    public preencherCategories({ component }: { component: Select }) {
        HttpCRUDTranslator.get('/CategoriaManut').then((response) => {
            component.datasource.updateData(response.data.data);
        }).catch((err) => {
            AlertService.show({
                name: 'error-alert',
                timeout: 5000,
                color: 'error',
                text: err,
            });
        });
    }

    public preencherEquipamentos({ component }: { component: Select }) {
        HttpCRUDTranslator.get('/getEquipamento').then((response) => {
            component.datasource.updateData(response.data.data);
        }).catch((err) => {
            AlertService.show({
                name: 'error-alert',
                timeout: 5000,
                color: 'error',
                text: err,
            });
        });
    }

    public preencherResponsavel() {
        const filter = [
            { name: 'NRFUNCIONARIO', operation: '=', value: this.atualNrFunc },
        ];
        HttpCRUDTranslator.get('/Funcionarios/PerfilAcesso', filter).then((response) => {
            const func = response.data.data;
            this.responsavel = func.NMFUNCIONARIO;
        }).catch((err) => {
            AlertService.show({
                name: 'error-alert',
                timeout: 5000,
                color: 'error',
                text: err,
            });
        });
    }

    public preencherImpactos({ component }: { component: Select }) {
        HttpCRUDTranslator.get('/getImpactoManutencao').then((response) => {
            component.datasource.updateData(response.data.data);
        }).catch((err) => {
            AlertService.show({
                name: 'error-alert',
                timeout: 5000,
                color: 'error',
                text: err,
            });
        });
    }

    public criarSolicitacaoServico() {
        // form = Metadata.getInstance<Form>('formSolicitacao');
        // const validate = form.validate();
        const categoria = Metadata.getInstance<Select>('selectServico').value;
        const equipamento = Metadata.getInstance<Select>('selectEquipamento').value;
        const impacto = Metadata.getInstance<Select>('selectImpacto').value;
        const descricao = Metadata.getInstance<Textarea>('textAreaDescricao').value;
        const nome = Metadata.getInstance<TextInput>('textInputNomeSolicitacao').value;

        const bodyPost = {
            NRCATEGORIAMANUT: parseInt(categoria, 10),
            // DTSOLICITACAOSERV: currentDate,
            // @toDo: remover esse valor fixo, obter pelo local storage
            NRFUNCSOLICITANTE: 2,
            NREQUIPAMENTO: parseInt(equipamento, 10),
            DSSOLICITACAOSERV: descricao,
            NRIMPACTOMANUT: parseInt(impacto, 10),
            NMSOLICITACAOSERV: nome,
        };

        HttpCRUDTranslator.post('/SolicitacaoServ', bodyPost).catch((err) => {
            AlertService.show({
                name: 'error-alert',
                timeout: 5000,
                color: 'error',
                text: err,
            });
        }).finally(() => {
            AlertService.show({
                name: 'success-alert',
                timeout: 5000,
                text: 'Solicitação de serviço criada com sucesso.',
                color: 'success',
            });
        });
    }
}
